Finish newdb -> dungeon renaming.
[open-adventure.git] / score.c
diff --git a/score.c b/score.c
index 0916b9a82bf740010f011393f97375f22db10094..d707fb8800fce8a95e78ade217cdd4810bf80972 100644 (file)
--- a/score.c
+++ b/score.c
@@ -1,7 +1,6 @@
 #include <stdlib.h>
 #include "advent.h"
-#include "database.h"
-#include "newdb.h"
+#include "dungeon.h"
 
 /*
  * scoring and wrap-up
@@ -37,8 +36,10 @@ long score(enum termination mode)
     /*  First tally up the treasures.  Must be in building and not broken.
      *  Give the poor guy 2 points just for finding each treasure. */
     mxscor = 0;
-    for (long i = MINTRS; i <= MAXTRS; i++) {
-        if (object_descriptions[i].inventory != 0) {
+    for (int i = 1; i <= NOBJECTS; i++) {
+       if (!objects[i].is_treasure)
+           continue;
+        if (objects[i].inventory != 0) {
             long k = 12;
             if (i == CHEST)k = 14;
             if (i > CHEST)k = 16;
@@ -50,14 +51,14 @@ long score(enum termination mode)
         }
     }
 
/*  Now look at how he finished and how far he got.  maximum_deaths and
      *  game.numdie tell us how well he survived.  game.dflag will tell us
      *  if he ever got suitably deep into the cave.  game.closng still
      *  indicates whether he reached the endgame.  And if he got as far as
      *  "cave closed" (indicated by "game.closed"), then bonus is zero for
      *  mundane exits or 133, 134, 135 if he blew it (so to speak). */
-    score += (maximum_deaths - game.numdie) * 10;
-    mxscor += maximum_deaths * 10;
+    score += (NDEATHS - game.numdie) * 10;
+    mxscor += NDEATHS * 10;
     if (mode == endgame)
         score += 4;
     mxscor += 4;
@@ -87,9 +88,9 @@ long score(enum termination mode)
     mxscor += 2;
 
     /* Deduct for hints/turns/saves. Hints < 4 are special; see database desc. */
-    for (long i = 1; i <= HNTMAX; i++) {
+    for (long i = 0; i < NHINTS; i++) {
         if (game.hinted[i])
-            score = score - hints[i-1].penalty;
+            score = score - hints[i].penalty;
     }
     if (game.novice)
         score -= 5;
@@ -115,7 +116,7 @@ void terminate(enum termination mode)
     if (points + game.saved + 1 >= mxscor && game.saved != 0)
         rspeak(WITHOUT_SUSPENDS);
     rspeak(TOTAL_SCORE, points, mxscor, game.turns, game.turns);
-    for (long i = 1; i <= (long)CLSSES; i++) {
+    for (long i = 1; i <= (long)NCLASSES; i++) {
         if (classes[i].threshold >= points) {
             speak(classes[i].message);
             i = classes[i].threshold + 1 - points;
@@ -50,14 +51,14 @@ long score(enum termination mode)
     }
 
-    /*  Now look at how he finished and how far he got.  maximum_deaths and
+    /*  Now look at how he finished and how far he got.  NDEATHS and
      *  game.numdie tell us how well he survived.  game.dflag will tell us
      *  if he ever got suitably deep into the cave.  game.closng still